Welcome to PyAstronomy
======================

PyAstronomy (PyA) is a collection of astronomy related packages
hosted on `github <https://github.com/sczesla/PyAstronomy>`_.

About PyAstronomy
-----------------

.. toctree::
   :maxdepth: 1
   
   pyaCDoc/whatIsIt.rst
   pyaCDoc/installingPyA.rst
   PyAGroup.rst
   license.rst
   pyaCDoc/acknowledgement.rst
   pyaCDoc/cont.rst

PyAstronomy's sub-packages
--------------------------

.. toctree::
   :maxdepth: 1

   Astrolib --- Routines for low-level data analysis and other small-scale applications <pyaslDoc/pyasl.rst>   
   PyaGUI --- GUI-based tools for the work with data <pyaGuiDoc/index.rst>
   Constants --- Numerical values for physical constants <constantsDoc/index.rst>
   Timing --- Tools for timing analysis such as Lomb-Scargle periodograms <pyTimingDoc/index.rst>
   
Model fitting
~~~~~~~~~~~~~
   
.. toctree::
   :maxdepth: 1
   
   funcFit --- A convenient fitting interface <funcFitDoc/index.rst>
   Model suite --- A collection of ready-to-use models for funcFit <modelSuiteDoc/index.rst>

.. toctree::
   :maxdepth: 1

   funcFit2 --- A new convenient fitting interface (beta) <funcFit2Doc/fuf2index.rst>

Spotlights
----------

.. toctree::
   :maxdepth: 1
   
   Beta-Sigma noise estimation <pyaslDoc/aslDoc/estimateSNR.rst>


PyAstronomy core
----------------

.. toctree::
   :maxdepth: 2
   
   pyaCDoc/index.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

